*******
Recipes
*******


This is a collection of how to use certain features of Antidote or simply examples of
what can be done.


.. toctree::
    :maxdepth: 2

    recipes/interface
    recipes/constant
    recipes/scopes
